"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Timeline = void 0;

var _types = require("./types");

var _util = require("./util");

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

class Timeline {
  constructor() {
    _defineProperty(this, "plugins", {});
  }

  add(plugin) {
    var _plugin$analytics, _plugin$analytics2;

    const {
      type
    } = plugin;

    if (this.plugins[type]) {
      var _this$plugins$type;

      (_this$plugins$type = this.plugins[type]) === null || _this$plugins$type === void 0 ? void 0 : _this$plugins$type.push(plugin);
    } else {
      this.plugins[type] = [plugin];
    }

    const settings = (_plugin$analytics = plugin.analytics) === null || _plugin$analytics === void 0 ? void 0 : _plugin$analytics.settings.get();
    let hasInitialSettings = false;

    if (settings !== undefined) {
      plugin.update({
        integrations: settings
      }, _types.UpdateType.initial);
      hasInitialSettings = true;
    }

    (_plugin$analytics2 = plugin.analytics) === null || _plugin$analytics2 === void 0 ? void 0 : _plugin$analytics2.settings.onChange(newSettings => {
      if (newSettings !== undefined) {
        plugin.update({
          integrations: newSettings
        }, hasInitialSettings ? _types.UpdateType.refresh : _types.UpdateType.initial);
        hasInitialSettings = true;
      }
    });
  }

  remove(plugin) {
    const plugins = this.plugins[plugin.type];

    if (plugins) {
      const index = plugins.findIndex(f => f === plugin);

      if (index > -1) {
        plugins.splice(index, 1);
      }
    }
  }

  apply(closure) {
    (0, _util.getAllPlugins)(this).forEach(plugin => closure(plugin));
  }

  async process(incomingEvent) {
    // apply .before and .enrichment types first ...
    const beforeResult = await this.applyPlugins({
      type: _types.PluginType.before,
      event: incomingEvent
    });

    if (beforeResult === undefined) {
      return;
    } // .enrichment here is akin to source middleware in the old analytics-ios.


    const enrichmentResult = await this.applyPlugins({
      type: _types.PluginType.enrichment,
      event: beforeResult
    });

    if (enrichmentResult === undefined) {
      return;
    } // once the event enters a destination, we don't want
    // to know about changes that happen there. those changes
    // are to only be received by the destination.


    await this.applyPlugins({
      type: _types.PluginType.destination,
      event: enrichmentResult
    }); // apply .after plugins ...

    let afterResult = await this.applyPlugins({
      type: _types.PluginType.after,
      event: enrichmentResult
    });
    return afterResult;
  }

  async applyPlugins(_ref) {
    let {
      type,
      event
    } = _ref;
    let result = event;
    const plugins = this.plugins[type];

    if (plugins) {
      for (const plugin of plugins) {
        if (result) {
          try {
            const pluginResult = plugin.execute(result); // Each destination is independent from each other, so we don't roll over changes caused internally in each one of their processing

            if (type !== _types.PluginType.destination) {
              result = await pluginResult;
            }
          } catch (error) {
            var _plugin$analytics3;

            (_plugin$analytics3 = plugin.analytics) === null || _plugin$analytics3 === void 0 ? void 0 : _plugin$analytics3.logger.warn(`Destination ${plugin.key} failed to execute: ${JSON.stringify(error)}`);
          }
        }
      }
    }

    return result;
  }

}

exports.Timeline = Timeline;
//# sourceMappingURL=timeline.js.map