import React, { createContext, useContext } from 'react';
import { defaultConfig } from './constants';
import { createLogger } from './logger';
import { SegmentClient } from './analytics';
import { SovranStorage } from './storage';
export const createClient = config => {
  const logger = (config === null || config === void 0 ? void 0 : config.logger) || createLogger();

  if (typeof (config === null || config === void 0 ? void 0 : config.debug) === 'boolean') {
    if (config.debug) {
      logger.enable();
    } else {
      logger.disable();
    }
  }

  const clientConfig = { ...defaultConfig,
    ...config
  };
  const segmentStore = new SovranStorage({
    storeId: config.writeKey,
    storePersistor: config.storePersistor
  });
  const client = new SegmentClient({
    config: clientConfig,
    logger,
    store: segmentStore
  });
  client.init();
  return client;
};
const Context = /*#__PURE__*/createContext(null);
export const AnalyticsProvider = _ref => {
  let {
    client,
    children
  } = _ref;

  if (!client) {
    return null;
  }

  return /*#__PURE__*/React.createElement(Context.Provider, {
    value: client
  }, children);
};
export const useAnalytics = () => {
  const client = useContext(Context);
  return React.useMemo(() => {
    if (!client) {
      console.error('Segment client not configured!', 'To use the useAnalytics() hook, pass an initialized Segment client into the AnalyticsProvider');
    }

    return {
      screen: async function () {
        for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
          args[_key] = arguments[_key];
        }

        return client === null || client === void 0 ? void 0 : client.screen(...args);
      },
      track: async function () {
        for (var _len2 = arguments.length, args = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
          args[_key2] = arguments[_key2];
        }

        return client === null || client === void 0 ? void 0 : client.track(...args);
      },
      identify: async function () {
        for (var _len3 = arguments.length, args = new Array(_len3), _key3 = 0; _key3 < _len3; _key3++) {
          args[_key3] = arguments[_key3];
        }

        return client === null || client === void 0 ? void 0 : client.identify(...args);
      },
      flush: async () => client === null || client === void 0 ? void 0 : client.flush(),
      group: async function () {
        for (var _len4 = arguments.length, args = new Array(_len4), _key4 = 0; _key4 < _len4; _key4++) {
          args[_key4] = arguments[_key4];
        }

        return client === null || client === void 0 ? void 0 : client.group(...args);
      },
      alias: async function () {
        for (var _len5 = arguments.length, args = new Array(_len5), _key5 = 0; _key5 < _len5; _key5++) {
          args[_key5] = arguments[_key5];
        }

        return client === null || client === void 0 ? void 0 : client.alias(...args);
      },
      reset: async function () {
        for (var _len6 = arguments.length, args = new Array(_len6), _key6 = 0; _key6 < _len6; _key6++) {
          args[_key6] = arguments[_key6];
        }

        return client === null || client === void 0 ? void 0 : client.reset(...args);
      }
    };
  }, [client]);
};
//# sourceMappingURL=client.js.map