function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import { UtilityPlugin } from '../plugin';
import { PluginType } from '../types';
export class DestinationMetadataEnrichment extends UtilityPlugin {
  constructor(destinationKey) {
    super();

    _defineProperty(this, "type", PluginType.enrichment);

    _defineProperty(this, "destinationKey", void 0);

    this.destinationKey = destinationKey;
  }

  execute(event) {
    var _this$analytics, _this$analytics2;

    const pluginSettings = (_this$analytics = this.analytics) === null || _this$analytics === void 0 ? void 0 : _this$analytics.settings.get();
    const plugins = (_this$analytics2 = this.analytics) === null || _this$analytics2 === void 0 ? void 0 : _this$analytics2.getPlugins(PluginType.destination);

    if (pluginSettings === undefined) {
      return event;
    } // Disable all destinations that have a device mode plugin


    const destinations = (plugins === null || plugins === void 0 ? void 0 : plugins.map(plugin => plugin.key)) ?? [];
    const bundled = new Set();

    for (const key of destinations) {
      if (key === this.destinationKey) {
        continue;
      }

      if (Object.keys(pluginSettings).includes(key)) {
        bundled.add(key);
      }
    }

    const unbundled = new Set();
    const segmentInfo = pluginSettings[this.destinationKey] ?? {};
    var unbundledIntegrations = segmentInfo.unbundledIntegrations ?? []; // All active integrations, not in `bundled` are put in `unbundled`
    // All unbundledIntegrations not in `bundled` are put in `unbundled`

    for (const integration in pluginSettings) {
      if (integration !== this.destinationKey && !bundled.has(integration)) {
        unbundled.add(integration);
      }
    }

    for (const integration of unbundledIntegrations) {
      if (!bundled.has(integration)) {
        unbundled.add(integration);
      }
    } // User/event defined integrations override the cloud/device mode merge


    const enrichedEvent = { ...event,
      _metadata: {
        bundled: Array.from(bundled),
        unbundled: Array.from(unbundled),
        bundledIds: []
      }
    };
    return enrichedEvent;
  }

}
//# sourceMappingURL=DestinationMetadataEnrichment.js.map