function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import { PlatformPlugin } from '../plugin';
import { EventType, PluginType } from '../types';
/**
 * This plugin injects the userInfo data into the event and also stores the changes applied by identify and alias calls into the state
 */

export class InjectUserInfo extends PlatformPlugin {
  constructor() {
    super(...arguments);

    _defineProperty(this, "type", PluginType.before);
  }

  async execute(event) {
    const userInfo = await this.analytics.userInfo.get(true);
    const injectedEvent = { ...event,
      anonymousId: userInfo.anonymousId,
      userId: userInfo.userId
    };

    if (event.type === EventType.IdentifyEvent) {
      await this.analytics.userInfo.set(state => ({ ...state,
        userId: event.userId ?? state.userId,
        traits: { ...state.traits,
          ...event.traits
        }
      }));
      return { ...injectedEvent,
        userId: event.userId ?? userInfo.userId,
        traits: { ...userInfo.traits,
          ...event.traits
        }
      };
    } else if (event.type === EventType.AliasEvent) {
      const {
        anonymousId,
        userId: previousUserId
      } = userInfo;
      await this.analytics.userInfo.set(state => ({ ...state,
        userId: event.userId
      }));
      return { ...injectedEvent,
        userId: event.userId,
        previousId: previousUserId || anonymousId
      };
    }

    return injectedEvent;
  }

}
//# sourceMappingURL=InjectUserInfo.js.map